%* sasdrugdev_adduserprivilege                                                                   *;
%*                                                                                               *;
%* Assign a global privilege to a user in the system.                                            *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ADDUSERPRIVILEGE(SDD_USERID=sdd-user-id, SDD_PRIVILEGE=sdd-privilege-id);         *;
%*                                                                                               *;
%* Example Code:                                                                                 *;
%* Use %sasdrugdev_getglobalprivileges to fetch the list of available global privileges. The     *;
%* macro returns a SAS data set containing the list of privileges (the default name of the       *;
%* data set is work.sddgetglobalprivileges).  Use one of the privilegeId values to assign that   *;
%* global privilege to a User.                                                                   *;
%*                                                                                               *;
%* 1. Retrieve the available global privileges:                                                  *;
%*    %sasdrugdev_getglobalprivileges();                                                         *;
%*                                                                                               *;
%* 2. Assign a privilege to a User:                                                              *;
%*    %sasdrugdev_adduserprivilege(sdd_userid=%str(User1),                                       *;
%*    sdd_privilege=%str(PRIVILEGE_AUDIT_REPORTING));                                            *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_userid - required - the user to assign the global privilege.                       *;
%* @param sdd_privilege - required - the identifier of the global privilege to assign.           *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-11-01 initial coding                                                            *;
%*                                                                                               *;

%macro sasdrugdev_adduserprivilege(
  sdd_userid=,
  sdd_privilege=
  ) /des='Assign a global privilege to a user.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/PrivilegeService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("addPrivilege", "%bquote(&sdd_userid)", "%bquote(&sdd_privilege)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" The global privilege &sdd_privilege has been assigned to the user &sdd_userid.." ;
    end;
    else
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot assign the global privilege &sdd_privilege to the user &sdd_userid.." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_adduserprivilege;
