%* sasdrugdev_assignedroleexists                                                                 *;
%*                                                                                               *;
%* Determine if a role exists (as defined or inherited) in an organization, project, or analysis.*;
%*                                                                                               *;
%* The SAS macro variable _sddAssignedRoleExists_ is set to a value of 1 if the role exists, 0   *;
%* if it does not.                                                                               *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ASSIGNEDROLEEXISTS (SDD_PATH=sdd-path, SDD_ROLE=sdd-role-name,                    *;
%* SDD_ROLE_CONTEXT=sdd-role-context);                                                           *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddAssignedRoleExists_  indicates the existence of the assigned role in the context. *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis).                                                                         *;
%* @param sdd_role - required - the name of the role to check for existence.                     *;
%* @param sdd_role_context - required - specifies the context in which the role is defined as a  *;
%*            path (e.g., /SAS).                                                                 *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_assignedroleexists(
  sdd_path=,
  sdd_role=,
  sdd_role_context=
  ) /des='Is the role assigned to a context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddAssignedRoleExists_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib exists          length=3;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RoleService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticBooleanMethod("assignedRoleExists", "%bquote(&sdd_path)", "%bquote(&sdd_role)", "%bquote(&sdd_role_context)", results, exists);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot determine the assignment of role &sdd_role_context &sdd_role in &sdd_path.." ;
      exists=-1;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      if (exists) then
      do;
        logMsg=" The role &sdd_role_context &sdd_role is assigned in &sdd_path.." ;
      end;
      else
      do;
        logMsg=" The role &sdd_role_context &sdd_role is not assigned in &sdd_path.." ;
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message;
    put logMsgPrefix " _sddRC_= " returnCode;
    put logMsgPrefix " _sddAssignedRoleExists_= " exists;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddAssignedRoleExists_", exists) ;

  run;

%mend sasdrugdev_assignedroleexists ;
