%* sasdrugdev_createfile                                                                         *;
%*                                                                                               *;
%* Uploads a file from the local machine to the SAS Drug Development repository.                 *;
%*                                                                                               *;
%* All parent folders that do not already exist will be created as well.                         *;
%*                                                                                               *;
%* NOTE: This macro is only supported from a PC SAS session. Using this macro within an active   *;
%* SAS Drug Development application session will result in a failure.                            *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_CREATEFILE(LOCAL_PATH=local-path, SDD_PATH=sdd-path                               *;
%* <, SDD_VERSIONING=sdd-versioning, SDD_VERSION=sdd-version, SDD_COMMENT=sdd_comment>);         *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param local_path - required - the absolute path and name of the file on the local computer.  *;
%* @param sdd_path - required - the path of the file to be created.                              *;
%* @param sdd_versioning - optional - indicates whether the file being created should be         *;
%*            versioned. The default value is 0, which will create a non-versioned file.  A      *;
%*            value of 1 will create a versioned file.                                           *;
%*            Values:  0 | 1                                                                     *;
%*            Default: 0                                                                         *;
%* @param sdd_version - conditional - indicates the version number to assign to the file being   *;
%*            created. The value must be in the valid version label format including a decimal   *:
%*            point.  This option is ignored when creating non-versioned file.                   *;
%* @param sdd_comment - conditional - the comment for the versioned file being created. This     *;
%*            option is ignored when creating a non-versioned file.                              *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.1                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_createfile(
  local_path=,
  sdd_path=,
  sdd_versioning=,
  sdd_version=,
  sdd_comment=
  ) /des='Upload a file from the local computer as a new file into SAS Drug Development.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RepositoryService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("createFile", "%bquote(&local_path)", "%bquote(&sdd_path)", "%bquote(&sdd_versioning)", "%bquote(&sdd_version)", "%bquote(&sdd_comment)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      if ("&sdd_versioning" eq "1") then
      do;
        logMsg=" Versioned file created as version &sdd_version at &sdd_path";
      end;
      else
      do;
        logMsg=" Unversioned file was created at &sdd_path";
      end;
    end;
    else
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" The file was not created: &sdd_path" ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put logMsgPrefix " local_path= &local_path" ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_createfile ;
