%* sasdrugdev_downloadaszip                                                                      *;
%*                                                                                               *;
%* Downloads SAS Drug Development files or a folder along with its content to your local machine *;
%* as a zip file.                                                                                *;
%*                                                                                               *;
%* If the local directory does not exist it will be created.  If the local file does not exist   *;
%* it will be created.  If the object being downloaded is a folder, the contents of the folder   *;
%* will be downloaded with its hierarchy maintained. If the object being downloaded is a project *;
%* or an analysis, only the containers (depots, folders) with files will be downloaded.          *;
%*                                                                                               *;
%* NOTE: This macro is only supported from a PC SAS session. Using this macro within an active   *;
%* SAS Drug Development application session will result in a failure.                            *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_DOWNLOADASZIP(SDD_PATH=sdd-path, LOCAL_PATH=local-zipfile-path                    *;
%* <,SDD_OVERWRITE=sdd-overwrite> );                                                             *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the object (file or container) to be downloaded.     *;
%* @param local_path - required - the full path and name of the file to create (or overwrite,    *;
%*            if applicable) on the local computer.                                              *;
%* @param sdd_overwrite - optional -  indicates whether or not to overwrite the existing zip     *;
%*            file on the local machine.  The valid values are 0 and 1 to maintain or overwrite  *;
%*            the file respectively.  The default is 0.                                          *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_downloadaszip(
  sdd_path=,
  local_path=,
  sdd_overwrite=0
  ) /des='Downloads a SAS Drug Development repository object as a zip file.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8 
           message         length=$200 
           logMsgPrefix    length=$70 
           logMsg          length=$300 
           rowCount        length=8
 
           sasLogFlag      length=$200
           sasLogAction    length=$200
           entryPath       length=$2048
    ;
    rowCount=0;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/BatchRepositoryService") ;
    declare javaobj results("com/sas/hls/macro/results/SasActionStatusResult");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("downloadAsZip", "%bquote(&sdd_path)", "%bquote(&local_path)", "%bquote(&sdd_overwrite)", results) ;

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);
    results.callIntMethod("getSize", rowCount);

    %***********************************;
    %* Print messages in log           *;
    %* Process the results             *;
    %***********************************;
    put;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Could not attempt the operation to download the object as a zip file: &sdd_path.." ;
      put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
      put logMsgPrefix " " logMsg;
      put logMsgPrefix " _sddMsg_= " message ;
      put logMsgPrefix " _sddRC_= " returnCode ;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" Attempted to download the object as a zip file: &sdd_path.." ;
      put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
      put logMsgPrefix " " logMsg;
      put logMsgPrefix " _sddMsg_= " message ;
    end;

    if (rowCount > 0) then
    do;
       macroNameStamp=strip(lowcase("&SYSMACRONAME")) || ": ";
       do row=0 to rowCount - 1;
         results.callStringMethod("getEntryPath",    row, entryPath);
         results.callStringMethod("getEntryStatus", row, sasLogFlag);
         results.callStringMethod("getEntryAction", row, sasLogAction);
         sasLogFlag   = strip(sasLogFlag)   || ": ";
         sasLogAction = strip(sasLogAction) || ": ";
         put sasLogFlag macroNameStamp sasLogAction entryPath;
       end;
    end;
    put "-" ;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_downloadaszip;
