%* sasdrugdev_downloadfile                                                                       *;
%*                                                                                               *;
%* Downloads a file to your local machine from the SAS Drug Development repository.              *;
%*                                                                                               *;
%* If the local directory does not exist it will be created.  If the local file does not exist   *;
%* it will be created.  If the local file does exist, it will be overwritten with new content.   *;
%*                                                                                               *;
%* NOTE: This macro is only supported from a PC SAS session. Using this macro within an active   *;
%* SAS Drug Development application session will result in a failure.                            *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_DOWNLOADFILE(SDD_PATH=sdd-path, SDD_VERSION=sdd- version>, LOCAL_PATH=local-path);*;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the file within the SAS Drug Development repository  *;
%*            to download.                                                                       *;
%* @param sdd_version - conditional - specifies the version of the file to download if the file  *;
%*            is versioned.  If the file is versioned and a specific version is specified the    *;
%*            value must be in the valid format including a decimal point such as 1.0 or 4.2.    *;
%*            If the file is versioned and no version is specified the latest version is         *;
%*            downloaded.  If the file is unversioned and a specific version is specified that   *;
%*            will result in a failure.                                                          *;
%* @param local_path - required - the full path and name of the file to create (or overwrite,    *;
%*            if it exists) on the local computer.                                               *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-10-30 initial coding                                                            *;
%*                                                                                               *;

%macro sasdrugdev_downloadfile(
  sdd_path=,
  sdd_version=,
  local_path=
  ) /des='Download a file to your local computer from the SAS Drug Development repository.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RepositoryService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("downloadFile", "%bquote(&sdd_path)", "%bquote(&sdd_version)", "%bquote(&local_path)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      if ("&sdd_version" eq " ") then
      do;
        logMsg=" Latest version of &sdd_path. was downloaded successfully to &local_path..";
      end;
      else
      do;
        logMsg=" Version &sdd_version. of &sdd_path. was downloaded successfully to &local_path..";
      end;
    end;
    else
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" The file was not downloaded: &sdd_path.." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_downloadfile;
