%* sasdrugdev_getassignedmembers                                                                 *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for all of the members assigned to the      *;
%* specified organization, project, or analysis.                                                 *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETASSIGNEDMEMBERS(SDD_PATH=sdd-path <, SAS_DSNAME=SAS-data-set>);                *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) containing the members.                                                  *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the members specified as libref.dataset. The default value is         *;
%*            WORK.SDDGETASSIGNEDMEMBERS. The data set contains a row for each member and        *;
%*            columns with the following names.  The data set will be sorted by member type      *;
%*            and principalId.                                                                   *;
%*            - contextPath: The path of the context object in the repository.                   *;
%*            - type:  The member type.  Valid values are USER and GROUP.                        *;
%*            - principalId: The name of the member.  The returned values will be either a group *;
%*                  name or a user ID.                                                           *;
%*            - description: The description of the member. The returned values will be either a *;
%*                  group name or a user display name.                                           *;
%*            - grpSrcCtxt: The context path in which the group member was defined if the member *;
%*                  is a group.                                                                  *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_getassignedmembers(
  sdd_path=,
  sas_dsname=work.sddGetAssignedMembers
  ) /des='Get a list of the assigned members in an SAS Drug Development context.';


  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %local _sddRowCount_;

  %let _sddRowCount_=0;

  %**********************************************;
  %*  Start the datastep to call the java code  *;
  %**********************************************;
  data &sas_dsname (
          label="Created by &SYSMACRONAME"
          keep=contextPath type principalId description grpSrcCtxt
          );
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib rowCount        length=8;
    
    attrib contextPath     length=$2048     label="Context Path" ;
    attrib type            length=$32       label="Principal Type";
    attrib principalId     length=$256      label="Principal Name";
    attrib description     length=$128      label="Principal Description";
    attrib grpSrcCtxt      length=$2048     label="Group Context Source Path";

    rowCount=0;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/MembershipService");
    declare javaobj results("com/sas/hls/macro/results/SasPrincipalsResult");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("getAssignedMembers", "%bquote(&sdd_path)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot retrieve assigned members for &sdd_path" ;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" Assigned members were returned for &sdd_path" ;
      results.callIntMethod("getSize", rowCount);
      do row=0 to rowCount - 1;
        contextPath="&sdd_path";
        results.callStringMethod("getType", row, type);
        results.callStringMethod("getName", row, principalId);
        results.callStringMethod("getDescription", row, description);
        results.callStringMethod("getContextPath", row, grpSrcCtxt);
        output;
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
      if (rowCount=0) then
          put logMsgPrefix " No members were found.";
      else
         put logMsgPrefix " " rowCount " records written to data set &sas_dsname";
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddRowCount_", rowCount);

  run;

  %***********************************;
  %* Sort the data set               *;
  %***********************************;
  %if (&_sddRowCount_ > 0) %then
  %do;
   %let notesOption=%sysfunc(getoption(notes));
    options nonotes;
    proc sort data=&sas_dsname;
      by type principalId;
    run;
    options &notesOption;
  %end;

%mend sasdrugdev_getassignedmembers;
