%* sasdrugdev_getconfiguration                                                                   *;
%*                                                                                               *;
%* Reports the current configuration settings.                                                   *;
%*                                                                                               *;
%* The values can be printed in the SAS log as well as being included in the data set.           *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETCONFIGURATION(<SAS_DSNAME=SAS-data-set, SAS_SUPPRESSLOGLIST=suppressloglist>); *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sas_dsname - optional - the name of the output SAS data set that contains the          *;
%*            configuration information as libref.dataset. The default value is                  *;
%*            WORK.SDDGETCONFIGURATION. The data set contains a row for each setting and columns *;
%*            with the following names. The data set will be sorted by name.                     *;
%*            - name: The name of the configuration item.                                        *;
%*            - value: The value of the configuration item.                                      *;
%*                                                                                               *;
%* @param sas_suppressLogList - optional - flag to suppress the print of the configuration       *;
%*            information to the log.  The default value is 0.  If the parameter is included     *;
%*            and the value is anything other than 0, the configuration values are not printed   *;
%*            to the log.                                                                        *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2014-04-04  changed exposure to external                                             *;
%*                                                                                               *;

%macro sasdrugdev_getconfiguration(
   sas_dsname=work.sddGetConfiguration,
   sas_suppressLogList=0
  ) /des='Get SAS Drug Development Macro configuration information.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data &sas_dsname (label="Created by &SYSMACRONAME"
                    keep=name value);
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib rowCount        length=8;

    attrib name            length=$128     label="Property Name";
    attrib value           length=$512     label="Property Value";

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/SystemService");
    declare javaobj results("com/sas/hls/macro/results/SasPropertiesResult");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("getConfiguration", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro: ";
      logMsg="Could not retrieve configuration information." ;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg="Configuration information was returned." ;
      results.callIntMethod("getSize", rowCount);
      do row=0 to rowCount - 1;
        results.callStringMethod("getPropertyName", row, name);
        results.callStringMethod("getPropertyValue", row, value);
        output;
        if ("&sas_suppressLogList" eq "0") then
            put name "= " value;
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix logMsg;
    put logMsgPrefix "_sddMsg_=" message ;
    put logMsgPrefix "_sddRC_=" returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_getconfiguration ;
