%* sasdrugdev_getglobalprivileges                                                                *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for all of the global privileges available  *;
%* in the system.                                                                                *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETGLOBALPRIVILEGES(<SAS_DSNAME=SAS-data-set>);                                   *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sas_dsname - optional - the name of the output SAS data set that contains the metadata *;
%*            for all of the global privileges specified as libref.dataset. The default value is *;
%*            WORK.SDDGETGLOBALPRIVILEGES.  The data set contains a row for each global privilege*;
%*            and columns with the following names. The data set will be sorted by privilegeId.  *;
%*            - privilegeId: The identifier of the privilege.                                    *;
%*            - privilegeName: The name of the privilege.                                        *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-11-01 initial coding                                                            *;
%* @history 2014-04-21 updated documentation                                                     *;
%*                                                                                               *;

%macro sasdrugdev_getglobalprivileges(
  sas_dsname=work.sddGetGlobalPrivileges
  )  /des='Get a list of all global privileges.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %local _sddRowCount_;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);
  %let _sddRowCount_=0;

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data &sas_dsname (label="Created by &SYSMACRONAME"
                    keep=privilegeId privilegeName);
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib rowCount        length=8;

    attrib privilegeId     length=$64      label="Privilege Identifier";
    attrib privilegeName   length=$128     label="Privilege Name";

    rowCount=0;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/PrivilegeService");
    declare javaobj results("com/sas/hls/macro/results/SasPrivilegesResult");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("getGlobalPrivileges", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot retrieve list of global privileges." ;
    end;
      else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" List of global privileges were returned." ;
      results.callIntMethod("getSize", rowCount);
      do row=0 to rowCount - 1;
        results.callStringMethod("getIdentifier", row, privilegeId);
        results.callStringMethod("getName", row, privilegeName);
        output;
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " " rowCount " records written to data set &sas_dsname";
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddRowCount_", rowCount);

  run;

  %***********************************;
  %* Sort by privilege id            *;
  %***********************************;
  %if (&_sddRowCount_ > 0) %then
  %do;
    %let notesOption=%sysfunc(getoption(notes));
    options nonotes;
    proc sort data=&sas_dsname;
      by privilegeId;
    run;
    options &notesOption;
  %end;

%mend sasdrugdev_getglobalprivileges;
