%* sasdrugdev_getjobinfo                                                                           *;
%*                                                                                                 *;
%* Returns a SAS data set that contains the information for a job in the SAS Drug Development      *;
%* repository. This is the information displayed on the General tab of the job editor, as well as  *;
%* the information concerning the versioning of new outputs.                                       *;
%*                                                                                                 *;
%* Syntax:                                                                                         *;
%* %SASDRUGDEV_GETJOBINFO(SDD_PATH=sdd-path <, SDD_VERSION=sdd-version, SAS_DSNAME=SAS-data-set>); *;
%*                                                                                                 *;
%* @macvar _sddRC_  the return code.                                                               *;
%* @macvar _sddMsg_ the return message.                                                            *;
%*                                                                                                 *;
%* @param sdd_path - required - the path of the job in the SAS Drug Development repository.        *;
%* @param sdd_version - optional - a specific version number of the job. If not specified,         *;
%*            the information for the latest version will be returned.  Specifying a version for   *;
%*            a non-versioned job will cause an error.                                             *;
%* @param sas_dsname - optional - the name of the output SAS data set that contains the metadata   *;
%*            for the job specified as libref.dataset. The default value is                        *;
%*            WORK.SDDGETJOBINFO. The data set will contain variables representing each            *;
%*            element of metadata for the object.  The data set will be sorted by the NAME         *;
%*            variable.  The following metadata will be represented in the data set.               *;
%*            - path: The path of the job.                                                         *;
%*            - versionLabel: The label associated with the specified version of the job.          *;
%*            - name: The name of the property or attribute.                                       *;
%*            - value: The value of the property or attribute.                                     *;
%*                                                                                                 *;
%* @macrotype SDD                                                                                  *;
%* @since 1.4                                                                                      *;
%* @exposure external                                                                              *;
%*                                                                                                 *;
%* @history 2014-04-08  initial coding.                                                            *;
%*                                                                                                 *;

%macro sasdrugdev_getjobinfo(
  sdd_path=,
  sdd_version=,
  sas_dsname=work.sddGetJobInfo
  ) /des='Get the metadata for SAS Drug Development repository job.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %local _sddRowCount_
         notesOption
  ;

  %let _sddRowCount_=0;

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data &sas_dsname (label="Created by &SYSMACRONAME"
                    keep=path versionLabel name value);
    attrib 
           returnCode      length=8
           message         length=$200
           logMsgPrefix    length=$70
           logMsg          length=$300           

           path            length=$2048    label="Job Path"  
           versionLabel    length=$32      label="Job Version Number"
           name            length=$256     label="Property Name" 
           value           length=$2048    label="Property Value" 

    ;

    rowCount=0;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/JobService") ;
    declare javaobj results("com/sas/hls/macro/results/SasPropertiesResult");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("getJobInfo", "%bquote(&sdd_path)", "%bquote(&sdd_version)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Could not retrieve job information." ;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" Retrieved job information.";
      results.callIntMethod("getSize", rowcount);
      do row=0 to rowCount - 1;
         path="&sdd_path";
         versionLabel="&sdd_version";
         results.callStringMethod("getPropertyName", row, name);
         results.callStringMethod("getPropertyValue", row, value);
         output;
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
      if (rowCount=0) then
        put logMsgPrefix " The job information was not found.";
      else
         put logMsgPrefix  rowCount " records written to data set &sas_dsname";
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddRowCount_", rowCount);

  run;

  %***********************************;
  %* Sort the data set               *;
  %***********************************;
  %if (&_sddRowCount_ > 0) %then
  %do;
    %let notesOption=%sysfunc(getoption(notes));
    options nonotes;
    proc sort data=&sas_dsname;
      by name;
    run;
    options &notesOption;
  %end;

%mend sasdrugdev_getjobinfo ;
