%* sasdrugdev_getobjecttype                                                                      *;
%*                                                                                               *;
%* Reports the SAS Drug Development object type for the specified                                *;
%* repository object path                                                                        *;
%*                                                                                               *;
%* The SAS macro variable _sddObjectType_ is set to the object type value.                       *;
%* The value is set to blank if the object could not be found or an error occurred.              *;
%* Possible object type values are:                                                              *;
%*    sas:analysis                                                                               *;
%*    sas:container                                                                              *;
%*    sas:file                                                                                   *;
%*    sas:folder                                                                                 *;
%*    sas:job                                                                                    *;
%*    sas:organization                                                                           *;
%*    sas:pdf                                                                                    *;
%*    sas:project                                                                                *;
%*    sas:sasdataset                                                                             *;
%*    sas:sasprogram                                                                             *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETOBJECTTYPE(SDD_PATH=sdd-path);                                                 *;
%*                                                                                               *;
%* @macvar _sddRC_         the return code.                                                      *;
%* @macvar _sddMsg_        the return message.                                                   *;
%* @macvar _sddObjectType_ the object type.                                                      *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the object for which the object type                 *;
%*                   will be retrieved.                                                          *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2014-03-07  initial coding                                                           *;
%*                                                                                               *;

%macro sasdrugdev_getobjecttype(
  sdd_path=
  ) /des='Get the SAS Drug Development object type for the specified path.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddObjectType_
          _sddRC_        
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib objectType      length=$30;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RepositoryService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticStringMethod("getObjectType", "%bquote(&sdd_path)", results, objectType);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Could not determine the object type: &sdd_path." ;
      objectType="";
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" The object type was returned for path: &sdd_path";
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix logMsg;
    put logMsgPrefix "_sddMsg_=" message ;
    put logMsgPrefix "_sddRC_=" returnCode ;
	put logMsgPrefix "_objectType_=" objectType ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddObjectType_", objectType) ;
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_getobjecttype ;
