%* sasdrugdev_getowner                                                                           *;
%*                                                                                               *;
%* Returns the current owner of an object within the organization in the SAS Drug Development    *;
%* repository.                                                                                   *;
%*                                                                                               *;
%* The macro variable _sddOwner_ will be set with the owner user ID. The value of _sddOwner_     *;
%* will be <creator> for the DEFAULT permissions on a container with no specific user designated *;
%* as the owner.                                                                                 *;
%*                                                                                               *;
%* Syntax for files:                                                                             *;
%* %SASDRUGDEV_GETOWNER(SDD_PATH =sdd-path);                                                     *;
%*                                                                                               *;
%* Syntax For containers:                                                                        *;
%* %SASDRUGDEV_GETOWNER(SDD_PATH =sdd-path, SDD_ACLTYPE =sdd-acl-type);                          *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddOwner_ the current owner of the object.                                           *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the content object in the SAS Drug Development       *;
%*            repository.                                                                        *;
%* @param sdd_aclType - conditional - the type of permissions being returned.  The valid values  *;
%*            are DEFAULT and CURRENT (case-insensitive). Files only have CURRENT permissions,   *;
%*            therefore, the value is not required when sdd_path is a file. For container        *;
%*            objects the value must be specified. The operation will fail if DEFAULT is         *;
%*            requested for a file path.                                                         *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_getowner(
  sdd_path=,
  sdd_aclType=
  ) /des='Get the owner of an object.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
      _sddOwner_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    
    attrib owner           length=$64;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/AclService") ;
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticStringMethod("getOwner", "%bquote(&sdd_path)", "%bquote(&sdd_aclType)", results, owner);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot retrieve owner of the &sdd_aclType ACL of &sdd_path.." ;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" The owner of the &sdd_aclType ACL of &sdd_path is " || owner ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddOwner_", owner) ;

  run;

%mend sasdrugdev_getowner;
