%* sasdrugdev_getsyncstatus                                                                      *;
%*                                                                                               *;
%* Determines if a file in the SAS Drug Development repository is synchronized, out of           *;
%* synchronization, or has never been synchronized with the workspace.                           *;
%*                                                                                               *;
%* The SAS macro variable _sddSyncStatus_ is set to the status value. The values are NOT_SYNCED, *;
%* IN_SYNC, and OUT_OF_SYNC.  If the file does not exist in either the workspace or the          *;
%* repository, the status is reported as NOT_SYNCED. If the object is a container, an error will *;
%* be reported.                                                                                  *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETSYNCSTATUS(SDD_PATH=sdd-path);                                                 *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddSyncStatus_ indicates the syncronization status.                                  *;
%*                                                                                               *;
%* @param sdd_path - required -  the path of the file.                                           *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2014-04-07  initial code                                                             *;
%*                                                                                               *;

%macro sasdrugdev_getsyncstatus(
  sdd_path=
  ) /des='What is the synchronization status of SAS Drug Development file?';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddSyncStatus_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib status          length=$25;

    status="";

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RepositoryService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticStringMethod("getSyncStatus", "%bquote(&sdd_path)", results, status);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot determine synchronization status: &sdd_path." ;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" Returned synchronization status: &sdd_path." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message;
    put logMsgPrefix " _sddRC_= " returnCode;
    put logMsgPrefix " _sddSyncStatus_= " status;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddSyncStatus_", strip(status) ) ;

  run;

%mend sasdrugdev_getsyncstatus ;
