%* sasdrugdev_getuserprivileges                                                                  *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for all of the global privileges assigned   *;
%* to a user within the system.                                                                  *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETUSERPRIVILEGES(SDD_USERID=sdd-userid <, SAS_DSNAME=SAS-data-set>);             *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_userid - required - the user to retrieve the global privileges for.                *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the global privileges specified as libref.dataset. The default value  *;
%*            is WORK.SDDGETUSERPRIVILEGES. The data set contains a row for each global privilege*;
%*            assigned to the user and the columns with the following names.  The data set will  *;
%*            be sorted by privilegeId.                                                          *;
%*            - userId: The user ID of the user.                                                 *;
%*            - privilegeId: The identifier of the privilege.                                    *;
%*            - privilegeName: The name of the privilege.                                        *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-11-01 initial coding                                                            *;
%*                                                                                               *;

%macro sasdrugdev_getuserprivileges(
  sdd_userid=,
  sas_dsname=work.sddGetUserPrivileges
  ) /des='Get a list of the global privileges assigned to a user.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %local _sddRowCount_;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);
  %let _sddRowCount_=0;

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data &sas_dsname (label="Created by &SYSMACRONAME"
                    keep=userId privilegeId privilegeName);
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib rowCount        length=8;

    attrib userId          length=$64      label="User ID";
    attrib privilegeId     length=$64      label="Privilege Identifier";
    attrib privilegeName   length=$128     label="Privilege Name";

    rowCount=0;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/PrivilegeService");
    declare javaobj results("com/sas/hls/macro/results/SasPrivilegesResult");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("getGrantedPrivileges", "%bquote(&sdd_userid)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot retrieve assigned global privileges for user &sdd_userid.." ;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" Global privileges were retrieved for user &sdd_userid" ;
      results.callIntMethod("getSize", rowCount);
      do row=0 to rowCount - 1;
        userId="&sdd_userid";
        results.callStringMethod("getIdentifier", row, privilegeId);
        results.callStringMethod("getName", row, privilegeName);
        output;
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
      if (rowCount=0) then
          put logMsgPrefix " No assigned global privileges were found.";
     else
         put logMsgPrefix " " rowCount " records written to data set &sas_dsname";
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddRowCount_", rowCount);

  run;

  %***********************************;
  %* Sort by privilege id            *;
  %***********************************;
  %if (&_sddRowCount_ > 0) %then
  %do;
    %let notesOption=%sysfunc(getoption(notes));
    options nonotes;
    proc sort data=&sas_dsname;
      by privilegeId;
    run;
    options &notesOption;
  %end;

%mend sasdrugdev_getuserprivileges;
