%* sasdrugdev_iscontainer                                                                        *;
%*                                                                                               *;
%* Determines whether a SAS Drug Development repository object is of type container.             *;
%*                                                                                               *;
%* The SAS macro variable _sddIsContainer_ is set to a value of 1 if the specified object is a   *;
%* container object, 0 if it is not.  Containers objects include folders, projects, analyses,    *;
%* and the organization.                                                                         *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ISCONTAINER(SDD_PATH=sdd-path);                                                   *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddIsContainer_ indicates if the object is a container.                              *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the object in the SAS Drug Development repository.   *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_iscontainer(
  sdd_path=
  ) /des='Is the object a container?';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddIsContainer_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib isContainer     length=3;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RepositoryService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticBooleanMethod("isContainer", "%bquote(&sdd_path)", results, isContainer);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot determine if the object is a container: &sdd_path." ;
      isContainer=-1;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      if (isContainer) then
      do;
        logMsg=" The object is a container: &sdd_path.";
      end;
      else
      do;
        logMsg=" The object is not a container: &sdd_path.";
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message;
    put logMsgPrefix " _sddRC_= " returnCode;
    put logMsgPrefix " _sddIsContainer_= " isContainer;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddIsContainer_", isContainer);

  run;

%mend sasdrugdev_iscontainer;
