%* sasdrugdev_ismember                                                                           *;
%*                                                                                               *;
%* Determines whether a user or group is a member in the specified organization, project,        *;
%* or analysis.                                                                                  *;
%*                                                                                               *;
%* The SAS macro variable _sddIsMember_ is set to a value of 1 when the specified user or group  *;
%* is a member of the context, 0 if it is not. Groups defined at the context level will not be   *;
%* considered as members of that context.                                                        *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ISMEMBER(SDD_PATH=sdd-path, SDD_MEMBER=sdd-member-identifier <, SDD_TYPE=sdd-type,*;
%* SDD_GROUP_CONTEXT=sdd-group-context>);                                                        *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddIsMember_ indicates if the user or group is a member of the specified             *;
%*            organization, project, or analysis.                                                *;
%*                                                                                               *;
%* @param sdd_path - required -  the path (starting at the root) context object (organization,   *;
%*            project, or analysis).                                                             *;
%* @param sdd_member - required - the user ID or group name of the member.                       *;
%* @param sdd_type - conditional - indicates the type of member. Valid values are USER and GROUP *;
%*            (case-insensitive).  The default value is USER.                                    *;
%* @param sdd_group_context - conditional - specifies the context in which the member group is   *;
%*            defined as a path (e.g., /SAS). The parameter is required if SDD_TYPE=GROUP.       *;
%*            Otherwise, it will be ignored.                                                     *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_ismember(
  sdd_path=,
  sdd_member=,
  sdd_type=USER,
  sdd_group_context=
  ) /des='Is the user or group a member in the specified context?';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddIsMember_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %*  Start the datastep to call the java code  *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib isMember        length=3;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/MembershipService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticBooleanMethod("isMember", "%bquote(&sdd_path)", "%bquote(&sdd_type)", "%bquote(&sdd_member)", "%bquote(&sdd_group_context)", results, isMember);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot determine if &sdd_type &sdd_group_context &sdd_member is a member of &sdd_path.";
      isMember=-1;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      if (isMember) then
      do;
        logMsg=" The &sdd_type &sdd_group_context &sdd_member is a member of &sdd_path.";
      end;
      else
      do;
        logMsg=" The &sdd_type &sdd_group_context &sdd_member is not a member of &sdd_path.";
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message;
    put logMsgPrefix " _sddRC_= " returnCode;
    put logMsgPrefix " _sddIsMember_= " isMember;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddIsMember_", isMember);

  run;

%mend sasdrugdev_ismember ;
