%* sasdrugdev_isroleprivilege                                                                    *;
%*                                                                                               *;
%* Determines whether a privilege is assigned to a role in the specified organization,           *;
%* project, or analysis.                                                                         *;
%*                                                                                               *;
%* The SAS macro variable _sddIsRolePrivilege_ is set to a value of 1 when the privilege is      *;
%* assigned, 0 if it is not.                                                                     *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ISROLEPRIVILEGE(SDD_PATH=sdd-path, SDD_ROLE=sdd-role-name,                        *;
%* SDD_PRIVILEGE=sdd-privilege-id);                                                              *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddIsRolePrivilege_ indicates if the privilege is assigned to the role in the        *;
%*            specified organization, project, or analysis.                                      *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the role is assigned.                                              *;
%* @param sdd_role - required - the name of the role.                                            *;
%* @param sdd_privilege - required - the identifier of the privilege to check.                   *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_isroleprivilege(
  sdd_path=,
  sdd_role=,
  sdd_privilege=
  ) /des='Is the privilege in the role in the specified context?';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddIsRolePrivilege_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;
    attrib hasPrivilege    length=3;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RoleService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticBooleanMethod("hasPrivilege", "%bquote(&sdd_path)", "%bquote(&sdd_role)", "%bquote(&sdd_privilege)", results, hasPrivilege);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot determine if &sdd_privilege is assigned to the role &sdd_role in &sdd_path..";
      hasPrivilege=-1;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      if (hasPrivilege) then
      do;
        logMsg=" &sdd_privilege is assigned to the role &sdd_role in &sdd_path.." ;
      end;
      else
      do;
        logMsg=" &sdd_privilege is not assigned to the role &sdd_role in &sdd_path.." ;
      end;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message;
    put logMsgPrefix " _sddRC_= " returnCode;
    put logMsgPrefix " _sddIsRolePrivilege_= " hasPrivilege;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);
    call symputx("_sddIsRolePrivilege_", hasPrivilege);

  run;

%mend sasdrugdev_isroleprivilege ;
