%* sasdrugdev_move                                                                               *;
%*                                                                                               *;
%* Moves a file or folder to the specified target location.                                      *;
%*                                                                                               *;
%* The item being moved must not already exist in the target location.                           *;
%* The children of a moved folder will also be moved to the target location,                     *;
%* keeping their directory structure and version history (if any) intact.                        *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_MOVE(SDD_SOURCE=sdd-source-path, SDD_TARGET=sdd-target-path);                     *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_source - required - the path of the object to be moved.                            *;
%* @param sdd_target - required - the path of the folder into which the object is to be          *;
%*            moved. The target folder must already exist. Path cannot end with a slash (/).     *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2014-03-03  initial coding                                                           *;
%*                                                                                               *;

%macro sasdrugdev_move(
  sdd_source=,
  sdd_target=
  ) /des='Move a file or folder.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %*  Start the datastep to call the java code  *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RepositoryService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("move", "%bquote(&sdd_source)", "%bquote(&sdd_target)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" The move operation was successful.";
    end;
    else
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot successfully move the object.  Target was not created." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put logMsgPrefix " sdd_source = &sdd_source" ;
    put logMsgPrefix " sdd_target = &sdd_target" ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_move ;
