%* sasdrugdev_submitjob                                                                          *;
%*                                                                                               *;
%* Submits a SAS Drug Development repository job for immediate execution and sets the SAS macro  *;
%* variable _sddJobSubmissionStatus_ to the identifier for the job submission. If the job cannot *;
%* be submitted, _sddJobSubmissionStatus_ will be set to blank.                                  *;
%*                                                                                               *;
%* A data set representing the job parameters whose values are to be overridden for the current  *;
%* job submission can be sent into the call of sasdrugdev_submitjob. If no job parameters data   *;
%* set is sent in, the default values for all job parameters will be used.                       *;
%* The output data set from the macro sasdrugdev_getjobparameters contains all the data relevant *;
%* to the parameters for a specific job and can be used as a source for the input parameters data*;
%* set for the sasdrugdev_submitjob macro. Modify the data set with any desired changes prior to *;
%* calling sasdrugdev_submitjob.                                                                 *;
%* - Rename the defaultValue variable to "value" or add a variable with the name "value" to      *;
%*   indicate the values to use for the current submission.                                      *;
%* - Default job parameter values will be used for missing parameters (deleted rows)             *;
%* - Indicating an empty string for a parameter value will result in using a blank as the        *;
%*   parameter value for the current submission.                                                 *;
%* - Added parameters will be ignored.                                                           *;
%* - The parameters in the input data set are matched with the job parameters by name and type.  *;
%*   If no match is found for a parameter, its default value will be used.                       *;
%* - Data set rows with duplicate values for parameter name will cause an execution error.       *;
%* - DATE job parameter values must be in SAS datetime18. format (e.g., 02NOV2013:09:33:22), or  *;
%*   in SAS E8601DZ25. format (e.g., 2013-11-02T09:33:22-04:00).  For SAS datetime18. format, an *;
%*   offset of zero hours from GMT will be used.  To specify an offset from GMT, use the         *;
%*   E8601DZ25. format.  Date values in formats other than the two described above will result   *;
%*   in an execution error.                                                                      *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_SUBMITJOB(SDD_PATH=sdd-path <, SDD_VERSION=sdd-version,                           *;
%*                       SAS_DSNAME=SAS-data-set>);                                              *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required -the path of the job in the SAS Drug Development repository.       *;
%* @param sdd_version - optional - a specific version number of the job. If not specified,       *;
%*            the latest version of the job will be submitted. Specifying a version for a        *;
%*            non-versioned file will cause an error.                                            *;
%* @param sas_dsname - optional - the name of the SAS data set containing the job parameter      *;
%*            information specified as libref.dataset. If not specified, the default job         *;
%*            parameters values will be used.  The data set must contain, at minimum, the        *;
%*            character variables listed below.  Any additional variables will be ignored.       *;
%*            - name: The name of the parameter.                                                 *;
%*            - type: The parameter type.  Valid values are CHARACTER, CHARACTER_MASKED,         *;
%*                  NUMERIC, DATE, FILE, and FOLDER.                                             *;
%*            - value: The value of the parameter to be used in the current job submission.      *;
%*            - fileVersion: The file version to be used if the parameter is of type FILE.       *;
%*                  For versioned files, a blank value will result in the latest file version    *;
%*                  used.  For nonversioned files, the value is ignored.                         *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2014-04-09  initial coding                                                           *;
%*                                                                                               *;

%macro sasdrugdev_submitjob(
   sdd_path=,
   sdd_version=,
   sas_dsname=
   ) /des='Submits a repository job for execution.';

   %****************************************;
   %* Initialize macro variables           *;
   %****************************************;
   %global _sddJobSubmissionId_
           _sddMsg_
           _sddRC_
   ;
   %local logMsgPrefix
          macroName
          notesOption
          parametersProvided
          _tempRUNJOB_tempDS_
   ;

   %let _sddJobSubmissionId_=;
   %let _sddRC_ =%str(-999);
   %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

   %let macroName=%sysfunc(lowcase(&SYSMACRONAME));
   %let logMsgPrefix=%str(ERR%str(OR): SAS Drug Development Macro: );
   %let parametersProvided=0;

   %*************************************************************;
   %* Turn off the notes generated for all the pre-processing.  *;
   %* Save original option setting so it can be reset properly. *;
   %*************************************************************;
   %let notesOption=%sysfunc(getoption(notes));
   options nonotes;

   %***************************************************************************;
   %* Cleanup from any previous runs that may have left temp data set behind. *;
   %***************************************************************************;
   %let _tempRUNJOB_tempDS_=%str(__SASMacro_runjobtemp__);

   %if (%sysfunc(exist(&_tempRUNJOB_tempDS_)) > 0) %then
   %do;
      %put NOTE: &macroName: Deleting temporary data set &_tempRUNJOB_tempDS_ before processing.;
      proc datasets library=work nolist;
         delete &_tempRUNJOB_tempDS_;
      quit; run;
   %end;

   %if ( %CMPRES(&sas_dsname) NE %str() ) %then
   %do;

      %***************************************************************************;
      %* Validate the parameters data set if supplied.                           *;
      %* sets global macro variable _sddRC_=0 if validation successful           *;
      %***************************************************************************;
      %sasdrugdev_validate_sasdataset(callingMacro=&macroName, 
                                      sas_dsn=&sas_dsname,
                                      required_variables=%str(name type value fileVersion)
      );
      %if (&_sddRC_ ne 0) %then
      %do;
         %GOTO PRINT_DSERROR_LOG_MSGS;
      %end;

      %*****************************************************************;
      %* Validate that no duplicate values are present for parameters. *;
      %* Order of original data set needs to be preserved.             *;
      %*****************************************************************;
      %PUT NOTE: TESTING FOR DUPLICATE PARAMETER VALUES.;

      %let _sddRC_ =%str(-999);
      %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

      proc sort data=&sas_dsname
                 out=&_tempRUNJOB_tempDS_;
         by name;
      run;
      data _null_;
         set &_tempRUNJOB_tempDS_;
         by name;
         if (first.name AND NOT(last.name)) then
         do;
            call symput("_sddMsg_", "Input data set has duplicate values for variable name.");
            STOP;
         end;
         call symput("_sddRC_", "0");
      run;
      %if (&_sddRC_ ne 0) %then
      %do;
         %GOTO PRINT_DSERROR_LOG_MSGS;
      %end;

      %let parametersProvided=1;
   %end;

   option notes;

   %**********************************************;
   %* Process the records                        *;
   %**********************************************;
   data _null_;
      attrib
               returnCode        length=8
               message           length=$200 
               jobSubmissionId   length=$525
      ;

      %if (&parametersProvided) %then
      %do;
         set &sas_dsname end=eof;

         if (_n_ = 1) then
         do;
      %end;

      %***********************************;
      %* Declare the java objects, once  *;
      %***********************************;
      declare javaobj params("com/sas/hls/macro/results/SasParameterValues");
      declare javaobj srv("com/sas/hls/macro/service/JobService");
      declare javaobj results("com/sas/hls/macro/results/Result");

      %if (&parametersProvided) %then
      %do;
         end;
         params.callVoidMethod("addValue", kstrip(name), kstrip(value), kstrip(type), kstrip(fileVersion));
         if (eof);
      %end;

      %***********************************;
      %* Submit the job                  *:
      %***********************************;
      srv.callStaticStringMethod("submitRepositoryJob", "%bquote(&sdd_path)", "%bquote(&sdd_version)", params, results, jobSubmissionId);

      %***********************************;
      %* Retrieve the results            *;
      %***********************************;
      results.callIntMethod("getReturnCode", returnCode);
      results.callStringMethod("getReturnMessage", message);

      %***********************************;
      %* Process the results             *;
      %***********************************;
      if (returnCode ne 0) then
      do;
         logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
         logMsg=" Cannot submit job &sdd_path.";
      end;
      else
      do;
         logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
         logMsg=" Submitted job &sdd_path.";
      end; 

      %***********************************;
      %* Print messages in log           *;
      %***********************************;
      put;
      put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
      put logMsgPrefix " " logMsg;
      put logMsgPrefix " _sddMsg_= " message ;
      put logMsgPrefix " _sddRC_= " returnCode ;
      %if (&sas_dsname EQ %str()) %then
      %do;
         put logMsgPrefix "No job parameters were supplied.";
      %end;
      %else
      %do; 
         put logMsgPrefix "sas_dsname = &sas_dsname";
      %end;
      put logMsgPrefix "_sddJobSubmissionId_= " jobSubmissionId;
      put;
      put;

      %***********************************;
      %* Set the macro variables         *;
      %***********************************;
      call symputx("_sddRC_", returnCode);
      call symputx("_sddMsg_", message);
      call symputx("_sddJobSubmissionId_", strip(jobSubmissionId));

   run;

   options &notesOption;

   %return;

   %PRINT_DSERROR_LOG_MSGS:
      options &notesOption;
      %put &logMsgPrefix  &macroName ;
      %put &logMsgPrefix _sddRC_= &_sddRC_ ;
      %put &logMsgPrefix _sddMsg_= &_sddMsg_ ;
      %put &logMsgPrefix Parameter data set = &sas_dsname;
      %put;

%mend sasdrugdev_submitjob;
