%* sasdrugdev_updateacls                                                                         *;
%*                                                                                               *;
%* Sets permissions on SAS Drug Development objects using a data set as input.                   *;
%*                                                                                               *;
%* This macro sets access permissions on repository objects using a SAS data set as input. The   *;
%* permission lists (known as Access Control Lists or ACLs) for multiple objects can be modified *;
%* using a single data set.  Access permissions are applied only to objects in the repository    *;
%* within the organization. There are two types of access permission lists: Current and Default. *;
%* The Current access permissions are applied to an individual object.  The Default access       *;
%* permissions apply only to container objects (e.g. folders, projects) and define the           *;
%* permissions that will be inherited by any new objects added to the container.  In the context *;
%* of this macro the access permission type is referred to as aclType.  All records in the input *;
%* data set that pertain to the same repository object and aclType will be processed together as *;
%* a single ACL.                                                                                 *;
%*                                                                                               *;
%* A set of permissions for a specific repository object for an individual principal within an   *;
%* access permission type are referred to as an Access Control Entry (ACE).  An ACE is           *;
%* represented as a single row in the input data set. An ACE is defined by the following         *;
%* characteristics:                                                                              *;
%* - path: Full path of the repository object (file or container) to which the permissions are   *;
%*   being assigned.                                                                             *;
%* - acl type: The access permission type is being assigned (DEFAULT or CURRENT)                 *;
%* - acl principal type: Identifies the type of the principal. The principal type can be Owner,  *;
%*   Members, User, or Group.                                                                    *;
%* - acl principal name: The name of the user or group to assign the permission to.              *;
%* - set of permissions: The specific permissions being assigned (e.g. administration, read,     *;
%*   properties write, content write, delete).                                                   *;
%*                                                                                               *;
%* The output data set from the sasdrugdev_getacls macro contains all the necessary variables    *;
%* and data needed as the input data set for the sasdrugdev_updateACLs macro. Modify the data    *;
%* set with any changes prior to calling sasdrugdev_updateacls.                                  *;
%* - To add a principal with specific access permissions to a repository object, add a new row   *;
%*   to the data set for that principal.                                                         *;
%* - To modify the access permissions for a principal already associated with a repository       *;
%*   object, edit the appropriate row in the data set.                                           *;
%* - To remove a principal with specific access permissions to a repository object, delete the   *;
%*   appropriate row from the data set. Note that the Owner and Members access control entries   *;
%*   cannot be removed from the object. Removing them from the data set will cause a failure.    *;
%* - To maintain the existing permissions for a principal already associated with a repository   *;
%*   object, leave the record as it is in the data set. The record must remain otherwise the     *;
%*   access permissions for this principal will be removed.                                      *;
%*                                                                                               *;
%* Failure and Message Handling:                                                                 *;
%* The macro performs a series of validation procedures to determine that the input data set has *;
%* the necessary structure for processing. If any of these validation procedures fail, an        *;
%* appropriate failure message is printed to the log and the macro stops additional processing.  *;
%*                                                                                               *;
%* In addition to other modifications, the macro sorts the input data set and stores the modified*;
%* data in a temporary data set called WORK.__SASMACRO_ACLTEMP__. In the event that a failure    *;
%* occurs during processing this temporary data set is retained as a reference. If all updates   *;
%* are performed successfully, this data set will be deleted from the work library.  A message   *;
%* will be printed to the log reporting whether the data set was retained or not. Regardless of  *;
%* success or failure of previous runs, this data set will be deleted at the beginning of each   *;
%* new run of the macro.  The data values and sort order of the original input data set are      *;
%* maintained.                                                                                   *;
%*                                                                                               *;
%* All records pertaining to the same repository object and aclType are processed as a single    *;
%* access control list by the macro. Messages will be printed to the log as each ACL is          *;
%* processed. If the update of an ACL fails, the macro will stop processing.                     *;
%*                                                                                               *;
%* If a failure occurs while processing a specific access control entry (i.e. a principal), the  *;
%* macro will stop processing and a failure message will be written to the log including the     *;
%* observation number for the entry that failed.  The observation number refers to the           *;
%* observation in the interim data set (WORK.__SASMACRO_ACLTEMP__) created by the macro.         *;
%* Successful updates to ACLs made prior to the observation containing the failure will be       *;
%* maintained in SAS Drug Development. Changes made to access permissions for entries that are   *;
%* part of the same ACL that contained the observation with the failure will be lost.            *;
%*                                                                                               *;
%* Valid values for permissions are as follows.  All values must be of type numeric.             *;
%*  1 for GRANT                                                                                  *;
%* -1 for DENY                                                                                   *;
%*  0 for inherited.                                                                             *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_UPDATEACLS(SAS_DSNAME=SAS-data-set);                                              *;
%*                                                                                               *;
%* Example Code:                                                                                 *;
%* Get permissions for a folder:                                                                 *;
%*                                                                                               *;
%* * start code example;                                                                         *;
%* %sasdrugdev_getacls(sdd_path=%str(/SAS/Study1/Files/folder1), sdd_recursive=0);               *;
%*                                                                                               *;
%* data UpdateACLS;                                                                              *;
%* set sddGetACLS end=eof;                                                                       *;
%*                                                                                               *;
%* output;                                                                                       *;
%*                                                                                               *;
%* if eof then do;                                                                               *;
%*   * Adding user permission under DEFAULT;                                                     *;
%*   aclType = "DEFAULT";                                                                        *;
%*   aclPrincipalType = "USER";                                                                  *;
%*   aclPrincipalName = "user1";                                                                 *;
%*   grpSrcCtxt = "";                                                                            *;
%*   adminPermission = 0;                                                                        *;
%*   readPermission = 1;                                                                         *;
%*   writePropPerm = 1;                                                                          *;
%*   writeContentPerm = 1;                                                                       *;
%*   deletePermission = 1;                                                                       *;
%*   output;                                                                                     *;
%*                                                                                               *;
%*   * Adding group permission under CURRENT;                                                    *;
%*   aclType = "CURRENT";                                                                        *;
%*   aclPrincipalType = "GROUP";                                                                 *;
%*   aclPrincipalName = "group1";                                                                *;
%*   grpSrcCtxt = "/SAS";                                                                        *;
%*   adminPermission = 0;                                                                        *;
%*   readPermission = 1;                                                                         *;
%*   writePropPerm = 1;                                                                          *;
%*   writeContentPerm = 1;                                                                       *;
%*   deletePermission = 1;                                                                       *;
%*   output;                                                                                     *;
%* end;                                                                                          *;
%*                                                                                               *;
%* run;                                                                                          *;
%*                                                                                               *;
%* %sasdrugdev_updateacls(sas_dsname=UpdateACLS);                                                *;
%* * end code example;                                                                           *;
%*                                                                                               *;
%* Note: Access Control Entries (ACEs) with values of 0 for all permission variables will be     *;
%*       removed from or will not be added to the ACL.                                           *;
%* Note: Users and groups being added as access control entries must be members in the context   *;
%*       (organization, project, analysis) containing the object being updated.                  *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sas_dsname - required - the name of a SAS data set containing the permission           *;
%*            information for all the objects to be modified specified as libref.dataset. The    *;
%*            data set must contain, at minimum, the variables listed below.  Any additional     *;
%*            variables will be ignored.                                                         *;
%*            - path: The case-sensitive path of the object including object name.               *;
%*            - aclType: Indicates which ACL to modify for the object. For Analysis and file     *;
%*                  objects, the variable must be present but the value will be ignored. For     *;
%*                  container objects, the value must be either DEFAULT or CURRENT               *;
%*                  (case-insensitive).                                                          *;
%*            - aclPrincipalType: Indicates the type of ACE being updated.                       *;
%*                  Values:  ACLOWNER | ACLMEMBERS | USER | GROUP (case-insensitive)             *;
%*                  Default: None                                                                *;
%*            - aclPrincipalName: The name of the principal ACE being updated or added.          *;
%*                  For aclPrincipalType ACLOWNER, this must have the value OWNER.               *;
%*                  For aclPrincipalType ACLMEMBERS, this must have the value MEMBERS.           *;
%*                  For aclPrincipalType USER, this must be a valid userid (case-sensitive).     *;
%*                  For aclPrincipalType GROUP, this must be a valid group name (case-sensitive).*;
%*            - grpSrcCtxt: The case-sensitive path of the context (organization, project, or    *;
%*                  analysis) where the group is defined if aclPrincipalType is GROUP. For       *;
%*                  aclPrincipalType GROUP, this value is required, otherwise the variable must  *;
%*                  be present but the value will be ignored.                                    *;
%*            - adminPermission: The permission to administer the object.                        *;
%*            - readPermission: The permission to view the object.                               *;
%*            - writePropPerm: The permission to update the properties of the object.            *;
%*            - writeContentPerm: The permission to write to the content of the object.          *;
%*            - deletePermission: The permission to the delete the object.                       *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_updateacls(
  sas_dsname=
  ) /des='Set permissions on SAS Drug Development objects.';

  %*************************************************************;
  %* Turn off the notes generated for all the pre-processing.  *;
  %* Save original option setting so it can be reset properly. *;
  %*************************************************************;
  %let notesOption=%sysfunc(getoption(notes));
  options nonotes;

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %***************************************************************************;
  %* Cleanup from any previous runs that may have left temp data set behind. *;
  %***************************************************************************;
  %let _tempACLUPDATE_tempDS_=%str(__SASMacro_acltemp__);

  %if (%sysfunc(exist(&_tempACLUPDATE_tempDS_)) > 0) %then
  %do;
    %put NOTE: sasdrugdev_updateacls: Deleting temporary data set &_tempACLUPDATE_tempDS_ before processing.;
    proc datasets library=work nolist;
      delete &_tempACLUPDATE_tempDS_;
    quit; run;
  %end;

  %***************************************************************************;
  %* Set local macro variables for processing.                               *;
  %*                                                                         *;
  %* setting a new macro variable for operation success because there are    *;
  %* operations in updateACL that could set _sddRC_ to something other than  *;
  %* 0 but still not be a failure.                                           *;
  %***************************************************************************;
  %local logMsgPrefix tempDsMsg;
  %let logMsgPrefix=%str(ERR%str(OR): SAS Drug Development Macro: );
  %let tempDsMsg=%str(Temporary sorted data set work.&_tempACLUPDATE_tempDS_ will not be created.);

  %***************************************************************************;
  %* Validate the input data set                                             *;
  %* sets global macro variable _sddRC_=0 if validation successful           *;
  %***************************************************************************;
  %let macroName=%sysfunc(lowcase(&SYSMACRONAME));
  %sasdrugdev_validate_sasdataset(callingMacro=&macroName, 
        sas_dsn=&sas_dsname,
        required_variables=%str(path aclType aclPrincipalType aclPrincipalName grpSrcCtxt 
                    adminPermission readPermission writePropPerm writeContentPerm deletePermission),
        required_numeric_variables=%str(adminPermission readPermission writePropPerm writeContentPerm deletePermission)
        );
  %if (&_sddRC_ ne 0) %then
  %do;
    %put &logMsgPrefix SAS Drug Development Macro &macroName ;
    %put &logMsgPrefix Input data set = &sas_dsname;
    %put &logMsgPrefix _sddRC_= &_sddRC_ ;
    %put &logMsgPrefix _sddMsg_= &_sddMsg_ ;
    %put &logMsgPrefix &tempDsMsg ;
    %put;
    %return;
  %end;

  %***************************************************************************;
  %* If data set is valid, process it.                                       *;
  %***************************************************************************;
  %put NOTE: &macroName: Processing data set &sas_dsname;

  %***************************************************************************;
  %* Clean the data set values                                               *;
  %* The data set that the user sends in can have very corrupt data.  Need   *;
  %* to clean it up (without changing the values) as much as possible before *;
  %* processing.                                                             *;
  %* Note: kstrip() of the required variables here did not help with sending *;
  %*       them into the macro.  Still had to do it there so I dropped it    *;
  %*       from here.                                                        *;
  %***************************************************************************;
  data &_tempACLUPDATE_tempDS_;
    attrib pathforsort  length=$2048  label="Path in uppercase for sorting purposes";
    set &sas_dsname;

    %*************************************************************************;
    %* Upcase values that should be case insensitive.  This is also for      *;
    %* sorting purposes.                                                     *;
    %* NOTE: PrincipalName and all paths must be case-sensitive              *;
    %*************************************************************************;
    aclType = upcase(aclType);
    aclPrincipalType = upcase(aclPrincipalType);

    %*************************************************************************;
    %* BUT path needs to be upcased to insure sorting purposes for SAS but   *;
    %* mixed case for SDD so am creating a separate variable for sorting.    *;
    %*************************************************************************;
    pathforsort = upcase(path);

  run;

  %************************;
  %* Sort the data        *;
  %************************;
  proc sort data=&_tempACLUPDATE_tempDS_
             out=&_tempACLUPDATE_tempDS_;
    by pathforsort aclType;
  run;

  option notes;

  %**********************************************;
  %* Process the records                        *;
  %**********************************************;
  data _null_;
    attrib returnCode               length=8;
    attrib message                  length=$200;
    attrib emptyAceCount            length=8;
    attrib aclUpdateCount           length=8;

    set &_tempACLUPDATE_tempDS_ end=eof;
      by pathforsort aclType;

    %***********************************;
    %* Declare the java objects, once  *;
    %***********************************;
    if (_n_ = 1) then
    do;
      declare javaobj acl("com/sas/hls/macro/results/SasAcl");
      declare javaobj srv("com/sas/hls/macro/service/AclService");
      declare javaobj results("com/sas/hls/macro/results/SasUpdateAclResult");

      put "NOTE: SAS Drug Development Macro: * " %sysfunc(lowcase("&SYSMACRONAME"));
      put "NOTE: SAS Drug Development Macro: * Input data set = &sas_dsname";
    end;

    if (first.aclType) then
    do;
      acl.callVoidMethod("resetAcl", kstrip(path), kstrip(aclType));
    end;

    %***********************************;
    %* Create a new ace                *:
    %***********************************;
    acl.callVoidMethod("addAce", kstrip(aclPrincipalType), kstrip(aclPrincipalName), kstrip(grpSrcCtxt),
                        readPermission, writePropPerm, writeContentPerm, deletePermission, adminPermission);

    if (last.aclType) then
    do;

      %***********************************;
      %* Call the update                 *:
      %***********************************;
      put "NOTE: SAS Drug Development Macro: * Processing " aclType "ACL for path " path;
      srv.callStaticVoidMethod("updateAcl", acl, results);

      %***********************************;
      %* Retrieve the results            *;
      %***********************************;
      results.callIntMethod("getReturnCode", returnCode);
      results.callStringMethod("getReturnMessage", message);

      %***********************************;
      %* Process the results             *;
      %***********************************;
      if (returnCode ne 0) then
      do;
        put "ERR%str(OR): SAS Drug Development Macro: * Unable to process " aclType "ACL for path " path;
        put "ERR%str(OR): SAS Drug Development Macro: * _sddMsg_ = " message;
        put "ERR%str(OR): SAS Drug Development Macro: * _sddRC_ = " returnCode;
        put;
        GO TO ENDPROCESS;
      end;
    end;

    if (eof) then
    do;
      GO TO ENDPROCESS;
    end;

    return;

    ENDPROCESS:
    results.callIntMethod("getAclUpdateCount", aclUpdateCount);
    results.callIntMethod("getBlankAceCount", emptyAceCount);
    if (emptyAceCount gt 0) then
    do;
      put "WARNING: SAS Drug Development Macro: * " emptyAceCount "record(s) had no permissions "
                    "explicitly set for the ACL being processed.  The ACE for those records was not "
                    "added or was removed from the ACL.";
    end;
    put "NOTE: SAS Drug Development Macro: * Successfully processed " aclUpdateCount "ACLs";
    put " ";

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

   option nonotes;

  %************************************************************;
  %* Cleanup temporary data set if the operation did not fail *;
  %************************************************************;
  %if (&_sddRC_ eq 0) %then
  %do;
    %if (%sysfunc(exist(&_tempACLUPDATE_tempDS_))>0) %then
    %do;
      %put NOTE: SAS Drug Development Macro: * %sysfunc(lowcase(&SYSMACRONAME)) is deleting temporary data set &_tempACLUPDATE_tempDS_;
      proc datasets library=work nolist;
        delete &_tempACLUPDATE_tempDS_;
        quit; run;
    %end;
  %end;
    %else
  %do;
    %put WARNING: SAS Drug Development Macro: * Temporary sorted data set work.&_tempACLUPDATE_tempDS_ is not being deleted.;
  %end;

  options &notesOption;

%mend sasdrugdev_updateacls;
