%* sasdrugdev_updatefile                                                                         *;
%*                                                                                               *;
%* Updates the contents of an existing file in the SAS Drug Development repository.              *;
%*                                                                                               *;
%* If the file is versioned a new version will be created.  If the file is not versioned, the    *;
%* existing contents will be overwritten.                                                        *;
%*                                                                                               *;
%* NOTE: This macro is only supported from a PC SAS session. Using this macro within an active   *;
%* SAS Drug Development application session will result in a failure.                            *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_UPDATEFILE(LOCAL_PATH=local-path, SDD_PATH=sdd-path <, SDD_COMMENT=sdd-comment>,  *;
%* SDD_VERSION=sdd-version-type);                                                                *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param local_path - required - the absolute path of the file on the local computer.           *;
%* @param sdd_path - required - the path of the content object in the SAS Drug Development       *;
%*            repository to update. The object must already exist and may not be a container.    *;
%* @param sdd_comment - conditional - the comment for a versioned file in the repository. This   *;
%*            value is ignored for non-versioned objects.                                        *;
%* @param sdd_version - conditional - the type of version to be created if the file to be        *;
%*            updated is versioned. Valid values are MAJOR or MINOR. The default is MINOR. This  *;
%*            value is ignored for non-versioned objects.                                        *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.1                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_updatefile(
  local_path=,
  sdd_path=,
  sdd_comment=,
  sdd_version=
  ) /des='Update the contents of an existing SAS Drug Development object.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RepositoryService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("updateFile", "%bquote(&local_path)", "%bquote(&sdd_path)", "%bquote(&sdd_version)", "%bquote(&sdd_comment)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" The file was updated: &sdd_path.." ;
    end;
    else
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot update file: &sdd_path.." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put logMsgPrefix " local_path= &local_path" ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_updatefile ;
