%* sasdrugdev_updateowner                                                                        *;
%*                                                                                               *;
%* Updates the current owner of an object within the organization in the SAS Drug Development    *;
%* repository.                                                                                   *;
%*                                                                                               *;
%* Syntax for files:                                                                             *;
%* %SASDRUGDEV_UPDATEOWNER(SDD_PATH=sdd-path, SDD_USERID=sdd-userid);                            *;
%*                                                                                               *;
%* Syntax for containers:                                                                        *;
%* %SASDRUGDEV_UPDATEOWNER(SDD_PATH=sdd-path, SDD_USERID=sdd-userid, SDD_ACLTYPE=sdd-acl-type);  *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the content object in the SAS Drug Development       *;
%*            repository.                                                                        *;
%* @param sdd_userid - required - the user ID for the account that will be the new owner. To set *;
%*            the owner for the DEFAULT permissions to be the creator of the objects, specify    *;
%*            the value <creator> as the value for sdd-userid.                                   *;
%* @param sdd_aclType - conditional - the type of permission owner being set. The valid values   *;
%*            are DEFAULT and CURRENT (case-insensitive). Files only have CURRENT permissions,   *;
%*            therefore, the value is not required when the sdd_path is a file. For container    *;
%*            objects the value must be specified. The operation will fail if DEFAULT is         *;
%*            requested for a file path.                                                         *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_updateowner(
  sdd_path=,
  sdd_aclType=,
  sdd_userid=
  ) /des='Change the owner of an object.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/AclService") ;
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("updateOwner", "%bquote(&sdd_path)", "%bquote(&sdd_aclType)", "%bquote(&sdd_userid)", results) ;

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" The owner of &sdd_aclType was changed to &sdd_userid for &sdd_path.." ;
    end;
    else
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot change the owner of &sdd_aclType to &sdd_userid for &sdd_path.." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_updateowner;
